!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
!   pd1 :    Time integration of a scalar nonlinear parabolic PDE
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
      SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
!     ---------- ---- 

      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM, ICP(*), IJAC
      DOUBLE PRECISION, INTENT(IN) :: U(NDIM), PAR(*)
      DOUBLE PRECISION, INTENT(OUT) :: F(NDIM)
      DOUBLE PRECISION, INTENT(INOUT) :: DFDU(NDIM,NDIM), DFDP(NDIM,*)
      DOUBLE PRECISION e
 
!      *Set the nonlinear term
	F(1)= U(1)*(1-U(1)) - PAR(4)*U(1)*U(2)
	F(2)=-PAR(2)*U(2)   + PAR(4)*U(1)*U(2) - PAR(5)*U(2)*U(3) &
					- PAR(1)*(1-EXP(-PAR(6)*U(2)))
        F(3)=-PAR(3)*U(3)   + PAR(5)*U(2)*U(3)

      END SUBROUTINE FUNC
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
      SUBROUTINE STPNT(NDIM,U,PAR,x)
!     ---------- ----- 

      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM
      DOUBLE PRECISION, INTENT(INOUT) :: U(NDIM),PAR(*)
      DOUBLE PRECISION, INTENT(IN) :: x
!
      INTEGER ID
      DOUBLE PRECISION pi, c
      pi=4*ATAN(1.d0)

!      Set the  parameters:
       PAR(1) = 0.0d0	! PAR(1) is reset in the script file
       PAR(2) = 0.25d0
       PAR(3) = 0.5d0
       PAR(4) = 4.d0
       PAR(5) = 3.d0
       PAR(6) = 5.d0

!      Set the actual width of the space interval [0,PAR(11)]:
       PAR(11) =15.	!PAR(11) is reset in the script file

!      Set the diffusion constants:
       PAR(15) = 0.1d0	!PAR(15) is reset in the script file
       PAR(16) = 0.5d0	!PAR(16) is reset in the script file
       PAR(17) = 1.d0	!PAR(17) is reset in the script file

!      Set the initial data in the (scaled) interval [0,1]:
       ID=1
       GOTO(1,2,3,4)ID
!---------------------
 1     c = 10.d0
       U(1) = x*(1-x)*DEXP(c*(x-1))
       U(2) = x*(1-x)*DEXP(-c*x)
       U(3) = x*(1-x)*DEXP(-c*x)
!      *Also set the space-derivative of the initial data
!      *Note the scaling by 1/PAR(11) !
       U(4) = c*(1-2*x)*DEXP(c*(x-1))/PAR(11)
       U(5) =-c*(1-2*x)*DEXP(-c*x)/PAR(11)
       U(6) =-c*(1-2*x)*DEXP(-c*x)/PAR(11)
       RETURN
!----------------
 2     c = 10.d0
       U(1) = x*(1-x)*DEXP(-c*x)
       U(2) = x*(1-x)*DEXP(c*(x-1))
       U(3) = x*(1-x)*DEXP(c*(x-1))
!      *Also set the space-derivative of the initial data
!      *Note the scaling by 1/PAR(11) !
       U(4) =-c*(1-2*x)*DEXP(-c*x)/PAR(11)
       U(5) = c*(1-2*x)*DEXP(c*(x-1))/PAR(11)
       U(6) = c*(1-2*x)*DEXP(c*(x-1))/PAR(11)
       RETURN
!----------------
 3     c = 0.1d0
       U(1) = c*(1.d0 + DCOS(2*pi*(x-0.5d0)))
       U(2) = c*(1.d0 + DCOS(2*pi*(x-0.5d0)))
       U(3) = c*(1.d0 + DCOS(2*pi*(x-0.5d0)))
!      *Also set the space-derivative of the initial data
!      *Note the scaling by 1/PAR(11) !
       U(4) =-c*2*pi*DSIN(2*pi*(x-0.5))/PAR(11)
       U(5) =-c*2*pi*DSIN(2*pi*(x-0.5))/PAR(11)
       U(6) =-c*2*pi*DSIN(2*pi*(x-0.5))/PAR(11)
       RETURN
!----------------
 4     c = 0.1d0
       U(1) = c*(1.d0 + DCOS(6*pi*(x-0.5d0)))
       U(2) = c*(1.d0 + DCOS(6*pi*(x-0.5d0)))
       U(3) = c*(1.d0 + DCOS(6*pi*(x-0.5d0)))
!      *Also set the space-derivative of the initial data
!      *Note the scaling by 1/PAR(11) !
       U(4) =-c*6*pi*DSIN(6*pi*(x-0.5))/PAR(11)
       U(5) =-c*6*pi*DSIN(6*pi*(x-0.5))/PAR(11)
       U(6) =-c*6*pi*DSIN(6*pi*(x-0.5))/PAR(11)
       RETURN

      END SUBROUTINE STPNT
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
      SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,FB,IJAC,DBC) 
!     ---------- ---- 

      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM, ICP(*), NBC, IJAC
      DOUBLE PRECISION, INTENT(IN) :: PAR(*), U0(NDIM), U1(NDIM)
      DOUBLE PRECISION, INTENT(OUT) :: FB(NBC)
      DOUBLE PRECISION, INTENT(INOUT) :: DBC(NBC,*)

!      *Define the boundary conditions.
       FB(1)=U0(1) 
       FB(2)=U0(2) 
       FB(3)=U0(3) 
       FB(4)=U1(1) 
       FB(5)=U1(2) 
       FB(6)=U1(3) 

      END SUBROUTINE BCND
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
      SUBROUTINE PVLS(NDIM,U,PAR)
!     ---------- ----
!
      IMPLICIT NONE
      INTEGER, INTENT(IN) :: NDIM
      DOUBLE PRECISION, INTENT(IN) :: U(NDIM)
      DOUBLE PRECISION, INTENT(INOUT) :: PAR(*)

      DOUBLE PRECISION, EXTERNAL :: GETP,GETU2
      INTEGER NDX,NCOL,NTST

! Get the integrals of U(1) and U(2)
       PAR(7)=GETP('INT',1,U)
       PAR(8)=GETP('INT',2,U)
       PAR(9)=GETP('INT',3,U)

      END SUBROUTINE PVLS
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
      SUBROUTINE ICND 
      END SUBROUTINE ICND

      SUBROUTINE FOPT 
      END SUBROUTINE FOPT
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
